# API Documentation

flarchitect automatically generates an OpenAPI 3.0.2 document for every
registered model. The specification powers an interactive documentation page
which can be served with either Redoc or Swagger UI. The raw specification is
standard OpenAPI and can be consumed by external tools such as Postman.

## Sections

- [Documentation style](documentation-style.md)
- [Automatic generation](automatic-generation.md)
- [Accessing the spec](accessing-the-spec.md)
- [Security scheme](security-scheme.md)
- [Exporting to a file](exporting-to-a-file.md)
- [Customising the document](customising-the-document.md)
- [Grouping and aggregation cards](grouping-and-aggregation-cards.md)
- [Error responses in the spec](error-responses-in-the-spec.md)
